==> Optik-1.2.tar.gz: Optik-1.2/test/test_help.py <==
#!/www/python/bin/python

# Test Optik help generation.  Not automated -- you have to read the
# output and see if it makes sense/looks good!

__revision__ = "$Id: test_help.py,v 1.3 2001/12/10 18:02:39 gward Exp $"

from optik import Option, OptionParser, SUPPRESS_HELP

hbar = "-"*72

options = [Option("-a", type="string", dest='a',
                  metavar="APPLE", help="throw APPLEs at basket"),
           Option("-b", "--boo", type="int", dest='boo',
                  metavar="NUM",
                  help="shout \"boo!\" NUM times (in order to frighten away "
                       "all the evil spirits that cause trouble and mayhem)"),
           Option("--foo", action="append", type="string", dest='foo',
                  help="store FOO in the foo list for later fooing"),
          ]
usage = "usage: %prog [options]"
parser = OptionParser(usage=usage, option_list=options)
parser.print_help()

print hbar

usage = "usage: %prog [options] arg1 arg2"
parser = OptionParser(usage)
parser.add_option("-v", "--verbose",
                  action="store_true", dest="verbose", default=1,
                  help="make lots of noise [default]")
parser.add_option("-q", "--quiet",
                  action="store_false", dest="verbose", 
                  help="be vewwy quiet (I'm hunting wabbits)")
parser.add_option("-f", "--file",
                  action="store", type="string", dest="filename",
                  metavar="FILE", help="write output to FILE"),
parser.add_option("-m", "--mode",
                  action="store", type="string", dest="mode",
                  default="intermediate",
                  help="interaction mode: one of 'novice', "
                       "'intermediate' [default], 'expert'")
parser.print_help()

==> Optik-1.3.tar.gz: Optik-1.3/test/test_help.py <==
#!/www/python/bin/python

# Test Optik help generation.  Not automated -- you have to read the
# output and see if it makes sense/looks good!

__revision__ = "$Id: test_help.py,v 1.4 2002/04/11 19:12:14 gward Exp $"

from optik import make_option, OptionParser, SUPPRESS_HELP

hbar = "-"*72

options = [
    make_option("-a", type="string", dest='a',
                metavar="APPLE", help="throw APPLEs at basket"),
    make_option("-b", "--boo", type="int", dest='boo',
                metavar="NUM",
                help="shout \"boo!\" NUM times (in order to frighten away "
                "all the evil spirits that cause trouble and mayhem)"),
    make_option("--foo", action="append", type="string", dest='foo',
                help="store FOO in the foo list for later fooing"),
    ]
usage = "usage: %prog [options]"
parser = OptionParser(usage=usage, option_list=options)
parser.print_help()

print hbar

usage = "usage: %prog [options] arg1 arg2"
parser = OptionParser(usage)
parser.add_option("-v", "--verbose",
                  action="store_true", dest="verbose", default=1,
                  help="make lots of noise [default]")
parser.add_option("-q", "--quiet",
                  action="store_false", dest="verbose", 
                  help="be vewwy quiet (I'm hunting wabbits)")
parser.add_option("-f", "--file",
                  action="store", type="string", dest="filename",
                  metavar="FILE", help="write output to FILE"),
parser.add_option("-m", "--mode",
                  action="store", type="string", dest="mode",
                  default="intermediate",
                  help="interaction mode: one of 'novice', "
                       "'intermediate' [default], 'expert'")
parser.print_help()
